@@ -26,6 +26,7 @@
 #include <QAction>
 #include <QApplication>
 #include <QDialog>
+#include <QMenu>
 #include <QVBoxLayout>
 #include <QStandardPaths>
 
@@ -113,3 +114,26 @@ bool MuonMainWindow::isConnected() const
 //     return connected;
     return true;
 }
+
+QList<QAction*> MuonMainWindow::setupMessageActions(QMenu* main, QMenu* advanced, const QList<QAction*> &actions)
+{
+    advanced->setEnabled(false);
+
+    QList<QAction*> ret;
+    foreach (QAction* action, actions) {
+        switch(action->priority()) {
+            case QAction::HighPriority:
+                ret += action;
+                break;
+            case QAction::NormalPriority:
+                main->addAction(action);
+                break;
+            case QAction::LowPriority:
+            default:
+                advanced->setEnabled(true);
+                advanced->addAction(action);
+                break;
+        }
+    }
+    return ret;
+}
