@@ -87,7 +87,7 @@ void ApplicationNotifier::checkUpgradeFinished(int exitStatus)
                                                 i18n("System update available!"),
                                                 i18nc("Notification when a new version of Kubuntu is available",
                                                       "A new version of Kubuntu is available"),
-                                                QIcon::fromTheme("svn-update").pixmap(KIconLoader::SizeMedium),
+                                                QStringLiteral("system-software-update"),
                                                 nullptr,
                                                 KNotification::CloseOnTimeout,
                                                 "muonapplicationnotifier");
@@ -135,14 +135,22 @@ void ApplicationNotifier::parseUpdateInfo()
         QByteArray updatesString = line.left(eqpos);
         QByteArray securityString = line.right(line.size() - eqpos - 1);
         
-        m_securityUpdates = securityString.toInt();
-        m_normalUpdates = updatesString.toInt() - m_securityUpdates;
+        int securityUpdates = securityString.toInt();
+        setUpdates(updatesString.toInt() - m_securityUpdates, securityUpdates);
     }
-    emit foundUpdates();
     
     m_checkingForUpdates = false;
 }
 
+void ApplicationNotifier::setUpdates(int normal, int security)
+{
+    if (m_normalUpdates != normal || security != m_securityUpdates) {
+        m_normalUpdates = normal;
+        m_securityUpdates = security;
+        emit foundUpdates();
+    }
+}
+
 bool ApplicationNotifier::isSystemUpToDate() const
 {
     return (m_securityUpdates+m_normalUpdates)==0;
