@@ -45,8 +45,18 @@ QString PackageKitResource::packageName() const
     return m_name;
 }
 
+QStringList PackageKitResource::allPackageNames() const
+{
+    return QStringList(m_name);
+}
+
 QString PackageKitResource::availablePackageId() const
 {
+    //First we check if it's upgradeable and use this version to display
+    const QString pkgid = backend()->upgradeablePackageId(this);
+    if (!pkgid.isEmpty())
+        return pkgid;
+
     QMap<PackageKit::Transaction::Info, QStringList>::const_iterator it = m_packages.constFind(PackageKit::Transaction::InfoAvailable);
     if (it != m_packages.constEnd())
         return it->first();
@@ -307,7 +317,7 @@ void PackageKitResource::fetchChangelog()
 static void addIfNotEmpty(const QString& title, const QString& content, QString& where)
 {
     if (!content.isEmpty())
-        where += QStringLiteral("<b>") + title + QStringLiteral("</b><p>&nbsp;") + content + QStringLiteral("</p>");
+        where += QStringLiteral("<p><b>") + title + QStringLiteral("</b>&nbsp;") + content + QStringLiteral("</p>");
 }
 
 static QString joinPackages(const QStringList& pkgids)
@@ -319,9 +329,17 @@ static QString joinPackages(const QStringList& pkgids)
     return ret.join(i18nc("comma separating package names", ", "));
 }
 
-void PackageKitResource::updateDetail(const QString& packageID, const QStringList& updates, const QStringList& obsoletes, const QStringList& vendorUrls,
-                                      const QStringList& bugzillaUrls, const QStringList& cveUrls, PackageKit::Transaction::Restart restart, const QString& updateText,
-                                      const QString& changelog, PackageKit::Transaction::UpdateState state, const QDateTime& issued, const QDateTime& updated)
+static QStringList urlToLinks(const QStringList& urls)
+{
+    QStringList ret;
+    foreach(const QString& in, urls)
+        ret += QStringLiteral("<a href='%1'>%1</a>").arg(in);
+    return ret;
+}
+
+void PackageKitResource::updateDetail(const QString& /*packageID*/, const QStringList& updates, const QStringList& obsoletes, const QStringList& vendorUrls,
+                                      const QStringList& /*bugzillaUrls*/, const QStringList& /*cveUrls*/, PackageKit::Transaction::Restart restart, const QString& updateText,
+                                      const QString& changelog, PackageKit::Transaction::UpdateState state, const QDateTime& /*issued*/, const QDateTime& /*updated*/)
 {
     QString info;
     addIfNotEmpty(i18n("Reason:"), updateText, info);
@@ -331,6 +349,9 @@ void PackageKitResource::updateDetail(const QString& packageID, const QStringLis
     addIfNotEmpty(i18n("Update State:"), PackageKitMessages::updateStateMessage(state), info);
     addIfNotEmpty(i18n("Restart:"), PackageKitMessages::restartMessage(restart), info);
 
+    if (!vendorUrls.isEmpty())
+        addIfNotEmpty(i18n("Vendor:"), urlToLinks(vendorUrls).join(QStringLiteral(", ")), info);
+
     emit changelogFetched(info);
 }
 
