@@ -25,29 +25,27 @@
 #include <QtConcurrentRun>
 #include <QApplication>
 #include <QtCore/QTimer>
-#include <QtGui/QHeaderView>
-#include <QtGui/QPushButton>
-#include <QtGui/QLabel>
-#include <QtGui/QSplitter>
+#include <QtWidgets/QHeaderView>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QLabel>
+#include <QSplitter>
 
 // KDE includes
-#include <KAction>
 #include <KComboBox>
 #include <KHBox>
-#include <KIcon>
 #include <KLineEdit>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMenu>
 #include <KMessageBox>
 #include <KPixmapSequence>
 #include <KPixmapSequenceOverlayPainter>
 #include <KVBox>
-#include <KDebug>
+#include <KIconLoader>
 
-// LibQApt includes
-#include <LibQApt/Backend>
-#include <LibQApt/DependencyInfo>
-#include <LibQApt/MarkingErrorInfo>
+// QApt includes
+#include <QApt/Backend>
+#include <QApt/DependencyInfo>
+#include <QApt/MarkingErrorInfo>
 
 // Own includes
 #include "../libmuonapt/ChangesDialog.h"
@@ -153,39 +151,39 @@ PackageWidget::PackageWidget(QWidget *parent)
 
 void PackageWidget::setupActions()
 {
-    m_installAction = new KAction(this);
-    m_installAction->setIcon(KIcon("download"));
+    m_installAction = new QAction(this);
+    m_installAction->setIcon(QIcon::fromTheme("download"));
     m_installAction->setText(i18nc("@action:inmenu", "Mark for Installation"));
     connect(m_installAction, SIGNAL(triggered()), this, SLOT(setPackagesInstall()));
 
-    m_removeAction = new KAction(this);
-    m_removeAction->setIcon(KIcon("edit-delete"));
+    m_removeAction = new QAction(this);
+    m_removeAction->setIcon(QIcon::fromTheme("edit-delete"));
     m_removeAction->setText(i18nc("@action:button", "Mark for Removal"));
     connect(m_removeAction, SIGNAL(triggered()), this, SLOT(setPackagesRemove()));
 
-    m_upgradeAction = new KAction(this);
-    m_upgradeAction->setIcon(KIcon("system-software-update"));
+    m_upgradeAction = new QAction(this);
+    m_upgradeAction->setIcon(QIcon::fromTheme("system-software-update"));
     m_upgradeAction->setText(i18nc("@action:button", "Mark for Upgrade"));
     connect(m_upgradeAction, SIGNAL(triggered()), this, SLOT(setPackagesUpgrade()));
 
-    m_reinstallAction = new KAction(this);
-    m_reinstallAction->setIcon(KIcon("view-refresh"));
+    m_reinstallAction = new QAction(this);
+    m_reinstallAction->setIcon(QIcon::fromTheme("view-refresh"));
     m_reinstallAction->setText(i18nc("@action:button", "Mark for Reinstallation"));
     connect(m_reinstallAction, SIGNAL(triggered()), this, SLOT(setPackagesReInstall()));
 
-    m_purgeAction = new KAction(this);
-    m_purgeAction->setIcon(KIcon("edit-delete-shred"));
+    m_purgeAction = new QAction(this);
+    m_purgeAction->setIcon(QIcon::fromTheme("edit-delete-shred"));
     m_purgeAction->setText(i18nc("@action:button", "Mark for Purge"));
     connect(m_purgeAction, SIGNAL(triggered()), this, SLOT(setPackagesPurge()));
 
-    m_keepAction = new KAction(this);
-    m_keepAction->setIcon(KIcon("dialog-cancel"));
+    m_keepAction = new QAction(this);
+    m_keepAction->setIcon(QIcon::fromTheme("dialog-cancel"));
     m_keepAction->setText(i18nc("@action:button", "Unmark"));
     connect(m_keepAction, SIGNAL(triggered()), this, SLOT(setPackagesKeep()));
 
-    m_lockAction = new KAction(this);
+    m_lockAction = new QAction(this);
     m_lockAction->setCheckable(true);
-    m_lockAction->setIcon(KIcon("object-locked"));
+    m_lockAction->setIcon(QIcon::fromTheme("object-locked"));
     m_lockAction->setText(i18nc("@action:button", "Lock Package at Current Version"));
     connect(m_lockAction, SIGNAL(triggered(bool)), this, SLOT(setPackagesLocked(bool)));
 }
@@ -341,11 +339,11 @@ void PackageWidget::contextMenuRequested(const QPoint &pos)
         if (state & QApt::Package::IsPinned) {
             m_lockAction->setChecked(true);
             m_lockAction->setText(i18nc("@action:button", "Unlock package"));
-            m_lockAction->setIcon(KIcon("object-unlocked"));
+            m_lockAction->setIcon(QIcon::fromTheme("object-unlocked"));
         } else {
             m_lockAction->setChecked(false);
             m_lockAction->setText(i18nc("@action:button", "Lock at Current Version"));
-            m_lockAction->setIcon(KIcon("object-locked"));
+            m_lockAction->setIcon(QIcon::fromTheme("object-locked"));
         }
     } else {
         m_installAction->setEnabled(true);
